@@ -21,6 +21,7 @@ else:
 
 __all__ = (
     "AttributeTypeType",
+    "AutoMLOverrideStrategyType",
     "DatasetTypeType",
     "DomainType",
     "EvaluationTypeType",
@@ -38,6 +39,7 @@ __all__ = (
 
 
 AttributeTypeType = Literal["float", "geolocation", "integer", "string", "timestamp"]
+AutoMLOverrideStrategyType = Literal["LatencyOptimized"]
 DatasetTypeType = Literal["ITEM_METADATA", "RELATED_TIME_SERIES", "TARGET_TIME_SERIES"]
 DomainType = Literal[
     "CUSTOM", "EC2_CAPACITY", "INVENTORY_PLANNING", "METRICS", "RETAIL", "WEB_TRAFFIC", "WORK_FORCE"
